@@ -3,6 +3,7 @@ from functools import wraps
 import sqlalchemy as sa
 from sqlalchemy.orm.collections import InstrumentedList as _InstrumentedList
 from sqlalchemy import types
+from .operators import CaseInsensitiveComparator
 
 
 class PhoneNumber(phonenumbers.phonenumber.PhoneNumber):
@@ -118,6 +119,16 @@ class ScalarList(types.TypeDecorator):
             )
 
 
+class Email(sa.types.TypeDecorator):
+    impl = sa.Unicode(255)
+    comparator_factory = CaseInsensitiveComparator
+
+    def process_bind_param(self, value, dialect):
+        if value is not None:
+            return value.lower()
+        return value
+
+
 class NumberRangeRawType(types.UserDefinedType):
     """
     Raw number range type, only supports PostgreSQL for now.
